<p>
  <img src="https://raw.githubusercontent.com/tukaan/.github/master/assets/tukaan.png" alt="Tukaan logo" width="140px" align="left">
  <h1 align="center">Tukaan</h1>
  <h4 align="center">Tukaan is a modern, cross platform Python toolkit for creating desktop GUI applications</h4>
</p>
</br>

---
<div align="center">

  [![tukaan.github.io](https://img.shields.io/badge/Website-tukaan.github.io-%23ec9f30)](https://tukaan.github.io)
  [![PyPI version](https://img.shields.io/pypi/v/tukaan)](https://pypi.org/project/tukaan)
  [![Downloads](https://static.pepy.tech/badge/tukaan)](https://pypi.org/project/tukaan)
  [![License: MIT](https://img.shields.io/badge/License-MIT-%236667ab.svg)](https://opensource.org/licenses/MIT)
  [![Code style: black](https://img.shields.io/badge/Code%20style-black-%23333333.svg)](https://github.com/psf/black)
  [![#StandWithUkraine](https://raw.githubusercontent.com/vshymanskyy/StandWithUkraine/main/badges/StandWithUkraine.svg)](https://www.standwithukraine.how/)
  
</div>

> With Tukaan you can make awesome modern GUI apps.
> Tukaan is intuitive and powerful - the complete opposite of Tkinter, although it was initially meant as an alternative to it.

---

> **Warning**
> After 1 year of development, this project is still in alpha state. You can install it and try it out, but I do not recommend to use it in your project, as **anything** may change in the future. 

## Get started

[Get started with Tukaan!](https://tukaan.github.io/docs)

## Contributing

If you like this project and want to contribute, you are very welcome to join the team!

## Credits
- Georgios Petasis, Kevin Walzer - [`tkdnd`](https://github.com/petasis/tkdnd)
- Aldo Buratti - [`extrafont`](https://sourceforge.net/projects/irrational-numbers/files/extrafont/)
- Cheer Xiao, Georgios Petasis, Geballin - [`TileGtk`](https://github.com/Geballin/gtkTtk)
- Inspiration
  - [Akuli/Teek](https://github.com/Akuli/teek)
  - [UnsignedArduino/TkZero](https://github.com/UnsignedArduino/TkZero)
  - [lawsie/guizero](https://github.com/lawsie/guizero)
  - Logo design inspired by [Tajulislam12's design on Dribbble](https://dribbble.com/shots/14487668-toucan-logo-design-Icon)


## FAQ

### Why did you name this project `Tukaan`?
Tk's logo is a feather, so I wanted to name the project after a bird with `T` and `K` in its name. So I came up with `tukán` (toucan in english). However Github doesn't allow non-english characters in repository names, so I had to simplify it to `Tukaan`.

### How do you pronounce `Tukaan`?
`tukaːn`
